@@ -7,12 +7,10 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-use Config::Model::BackendMgr;
+use strict;
+use warnings;
 
-$conf_dir = '/etc';
-$conf_file_name = 'hosts.yaml';
-
-$model->create_config_class(
+my @config_classes = ({
     name => 'Host',
 
     element => [
@@ -22,8 +20,9 @@ $model->create_config_class(
         },
         dummy => {qw/type leaf value_type uniline/},
     ]
-);
-$model->create_config_class(
+});
+
+push @config_classes, {
     name => 'Hosts',
 
     rw_config => {
@@ -43,11 +42,9 @@ $model->create_config_class(
             },
         },
     ]
-);
+};
 
-$model_to_test = "Hosts";
-
-@tests = (
+my @tests = (
     {
         name  => 'basic',
         check => [
@@ -57,4 +54,11 @@ $model_to_test = "Hosts";
     },
 );
 
-1;
+return {
+    model_to_test => "Hosts",
+    conf_dir => '/etc',
+    conf_file_name => 'hosts.yaml',
+    config_classes => \@config_classes,
+    tests => \@tests
+};
+
